function [PSF, center] = psfGauss(dim, sigma)
% PSFGAUSS Constructs a Gaussian blur point spread function.
% 
% [PSF, center] = psfGauss(dim, sigma)
%           PSF = psfGauss(dim);
%           PSF = psfGauss(dim, sigma);
% Inputs:
%    dim       Desired dimension of the PSF array.  For example,
%              PSF = psfGauss([60,60]) creates a 60-by-60 array.
%    sigma     Variance of the Gaussian, default is sigma = 2.0.
%
% Output:
%    PSF       Array containing the point spread function.
%    center    [row, col] gives index of center of PSF.

% Reference: 
%
% P. C. Hansen, J. Nagy, D. O'Leary -- Deblurring Images: Matrices, 
% Spectra, and Filtering, SIAM, 2006.

if ( nargin < 2 )
  sigma=2.0;
end

l = length(dim);
if l == 1
  m = dim;
  n = dim;
else
  m = dim(1);
  n = dim(2);
end

x = -fix(m/2):ceil(m/2)-1;
y = -fix(n/2):ceil(n/2)-1;

[X,Y] = meshgrid(x,y);
PSF = exp( -(X.^2 + Y.^2) / (2*sigma^2) ) / ( sqrt((2*pi)^l)*sigma^l );
PSF = PSF / sum(PSF(:));
if nargout == 2
  [mm, nn] = find(PSF == max(PSF(:)));
  center = [mm, nn];
end